@@ -1,4 +1,4 @@
-#' Some animals, their types and their masses
+#' Some animals and their attributes
 #'
 #' @format A data frame with 6 rows and 4 variables:
 #' \describe{
@@ -9,6 +9,17 @@
 #' }
 "animals"
 
+#' Some animals and their attributes, in rich text
+#'
+#' @format A data frame with 6 rows and 4 variables:
+#' \describe{
+#'   \item{animal}{the name of the animal}, in rich text 
+#'   \item{type}{the type of animal} 
+#'   \item{flies}{whether the animal can fly} 
+#'   \item{mass}{the average mass of the animal in grams} 
+#' }
+"animals_rich"
+
 #' The compositions of some espresso-based beverages
 #'
 #' @format A data frame with 6 rows and 3 variables:
@@ -19,6 +30,16 @@
 #' }
 "beverages"
 
+#' The compositions of some espresso-based beverages, in rich text
+#'
+#' @format A data frame with 6 rows and 3 variables:
+#' \describe{
+#'   \item{beverage}{the name of the beverage} 
+#'   \item{ingredient}{the ingredient, in rich text} 
+#'   \item{proportion}{the proportion of a cup to fill with the ingredient} 
+#' }
+"beverages_rich"
+
 #' Some craft and their altitudes
 #'
 #' @format A data frame with 4 rows and 2 variables:
@@ -33,10 +54,10 @@
 #' @format A data frame with 8 rows and 5 variables:
 #' \describe{
 #'   \item{line}{a line from the poem} 
-#'   \item{xmin}{the xmin coordinate with which to draw the word} 
-#'   \item{xmax}{the xmax coordinate with which to draw the word} 
-#'   \item{ymin}{the ymin coordinate with which to draw the word} 
-#'   \item{ymax}{the ymax coordinate with which to draw the word} 
+#'   \item{xmin}{the xmin coordinate with which to draw the line} 
+#'   \item{xmax}{the xmax coordinate with which to draw the line} 
+#'   \item{ymin}{the ymin coordinate with which to draw the line} 
+#'   \item{ymax}{the ymax coordinate with which to draw the line} 
 #'   \item{linenumber}{the line number} 
 #' }
 "gold"
